@@ -69,7 +69,7 @@ class Catch22Classifier(BaseClassifier):
     >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
     >>> clf = Catch22Classifier(
-    ...     estimator=RandomForestClassifier(n_estimators=10),
+    ...     estimator=RandomForestClassifier(n_estimators=5),
     ...     outlier_norm=True,
     ... )
     >>> clf.fit(X_train, y_train)
@@ -183,9 +183,19 @@ class Catch22Classifier(BaseClassifier):
             return dists
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
         Returns
         -------
         params : dict or list of dict, default={}
@@ -194,5 +204,10 @@ class Catch22Classifier(BaseClassifier):
             `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
             `create_test_instance` uses the first (or only) dictionary in `params`.
         """
-        params = {"estimator": RandomForestClassifier(n_estimators=2)}
-        return params
+        if parameter_set == "results_comparison":
+            return {
+                "estimator": RandomForestClassifier(n_estimators=10),
+                "outlier_norm": True,
+            }
+        else:
+            return {"estimator": RandomForestClassifier(n_estimators=2)}
