@@ -180,7 +180,7 @@ class RandomIntervalSpectralEnsemble(BaseClassifier):
     >>> from sktime.datasets import load_unit_test
     >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
-    >>> clf = RandomIntervalSpectralEnsemble(n_estimators=10)
+    >>> clf = RandomIntervalSpectralEnsemble(n_estimators=5)
     >>> clf.fit(X_train, y_train)
     RandomIntervalSpectralEnsemble(...)
     >>> y_pred = clf.predict(X_test)
@@ -188,6 +188,7 @@ class RandomIntervalSpectralEnsemble(BaseClassifier):
 
     _tags = {
         "capability:multithreading": True,
+        "classifier_type": "interval",
     }
 
     def __init__(
@@ -302,7 +303,7 @@ class RandomIntervalSpectralEnsemble(BaseClassifier):
 
         return self
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Find predictions for all cases in X.
 
         Built on top of `predict_proba`.
@@ -322,7 +323,7 @@ class RandomIntervalSpectralEnsemble(BaseClassifier):
         proba = self._predict_proba(X)
         return np.asarray([self.classes_[np.argmax(prob)] for prob in proba])
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Find probability estimates for each class for all cases in X.
 
         Parameters
@@ -370,6 +371,37 @@ class RandomIntervalSpectralEnsemble(BaseClassifier):
 
         return np.sum(all_proba, axis=0) / self.n_estimators
 
+    @classmethod
+    def get_test_params(cls, parameter_set="default"):
+        """Return testing parameter settings for the estimator.
+
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        if parameter_set == "results_comparison":
+            return {"n_estimators": 10}
+        else:
+            return {
+                "n_estimators": 2,
+                "acf_lag": 10,
+                "min_interval": 5,
+            }
+
 
 @jit(parallel=True, cache=True, nopython=True)
 def acf(x, max_lag):
