@@ -28,7 +28,8 @@ from sktime.datasets import (
     load_uschange,
     write_dataframe_to_tsfile,
 )
-from sktime.datasets._data_io import MODULE
+from sktime.datasets._data_io import MODULE, _convert_tsf_to_hierarchical
+from sktime.datatypes import check_is_mtype
 
 
 def test_load_from_tsfile():
@@ -1083,18 +1084,217 @@ def test_write_dataframe_to_ts_fail(tmp_path):
         )
 
 
-def test_load_tsf_to_dataframe():
+@pytest.mark.parametrize(
+    "input_path, return_type, output_df",
+    [
+        (
+            "datasets/data/UnitTest/UnitTest_Tsf_Loader.tsf",
+            "default_tsf",
+            pd.DataFrame(
+                {
+                    "series_name": ["T1", "T2", "T3"],
+                    "start_timestamp": [
+                        pd.Timestamp(year=1979, month=1, day=1),
+                        pd.Timestamp(year=1979, month=1, day=1),
+                        pd.Timestamp(year=1973, month=1, day=1),
+                    ],
+                    "series_value": [
+                        [
+                            25092.2284,
+                            24271.5134,
+                            25828.9883,
+                            27697.5047,
+                            27956.2276,
+                            29924.4321,
+                            30216.8321,
+                        ],
+                        [887896.51, 887068.98, 971549.04],
+                        [227921, 230995, 183635, 238605, 254186],
+                    ],
+                }
+            ),
+        ),
+        (
+            "datasets/data/UnitTest/UnitTest_Tsf_Loader_hierarchical.tsf",
+            "pd_multiindex_hier",
+            pd.DataFrame(
+                data=[
+                    25092.2284,
+                    24271.5134,
+                    25828.9883,
+                    27697.5047,
+                    27956.2276,
+                    29924.4321,
+                    30216.8321,
+                    887896.51,
+                    887068.98,
+                    971549.04,
+                    227921,
+                    230995,
+                    183635,
+                    238605,
+                    254186,
+                ],
+                index=pd.MultiIndex.from_tuples(
+                    [
+                        ("G1", "T1", pd.Timestamp(year=1979, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1980, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1981, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1982, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1983, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1984, month=1, day=1)),
+                        ("G1", "T1", pd.Timestamp(year=1985, month=1, day=1)),
+                        ("G1", "T2", pd.Timestamp(year=1979, month=1, day=1)),
+                        ("G1", "T2", pd.Timestamp(year=1980, month=1, day=1)),
+                        ("G1", "T2", pd.Timestamp(year=1981, month=1, day=1)),
+                        ("G2", "T3", pd.Timestamp(year=1973, month=1, day=1)),
+                        ("G2", "T3", pd.Timestamp(year=1974, month=1, day=1)),
+                        ("G2", "T3", pd.Timestamp(year=1975, month=1, day=1)),
+                        ("G2", "T3", pd.Timestamp(year=1976, month=1, day=1)),
+                        ("G2", "T3", pd.Timestamp(year=1977, month=1, day=1)),
+                    ],
+                    names=["series_group", "series_name", "timestamp"],
+                ),
+                columns=["series_value"],
+            ),
+        ),
+        (
+            "datasets/data/UnitTest/UnitTest_Tsf_Loader.tsf",
+            "pd-multiindex",
+            pd.DataFrame(
+                data=[
+                    25092.2284,
+                    24271.5134,
+                    25828.9883,
+                    27697.5047,
+                    27956.2276,
+                    29924.4321,
+                    30216.8321,
+                    887896.51,
+                    887068.98,
+                    971549.04,
+                    227921,
+                    230995,
+                    183635,
+                    238605,
+                    254186,
+                ],
+                index=pd.MultiIndex.from_tuples(
+                    [
+                        ("T1", pd.Timestamp(year=1979, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1980, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1981, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1982, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1983, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1984, month=1, day=1)),
+                        ("T1", pd.Timestamp(year=1985, month=1, day=1)),
+                        ("T2", pd.Timestamp(year=1979, month=1, day=1)),
+                        ("T2", pd.Timestamp(year=1980, month=1, day=1)),
+                        ("T2", pd.Timestamp(year=1981, month=1, day=1)),
+                        ("T3", pd.Timestamp(year=1973, month=1, day=1)),
+                        ("T3", pd.Timestamp(year=1974, month=1, day=1)),
+                        ("T3", pd.Timestamp(year=1975, month=1, day=1)),
+                        ("T3", pd.Timestamp(year=1976, month=1, day=1)),
+                        ("T3", pd.Timestamp(year=1977, month=1, day=1)),
+                    ],
+                    names=["series_name", "timestamp"],
+                ),
+                columns=["series_value"],
+            ),
+        ),
+        (
+            "datasets/data/UnitTest/UnitTest_Tsf_Loader_no_start_timestamp.tsf",
+            "default_tsf",
+            pd.DataFrame(
+                {
+                    "series_name": ["T1", "T2", "T3"],
+                    "series_value": [
+                        [
+                            25092.2284,
+                            24271.5134,
+                            25828.9883,
+                            27697.5047,
+                            27956.2276,
+                            29924.4321,
+                            30216.8321,
+                        ],
+                        [887896.51, 887068.98, 971549.04],
+                        [227921, 230995, 183635, 238605, 254186],
+                    ],
+                }
+            ),
+        ),
+        (
+            "datasets/data/UnitTest/UnitTest_Tsf_Loader_no_start_timestamp.tsf",
+            "pd-multiindex",
+            pd.DataFrame(
+                data=[
+                    25092.2284,
+                    24271.5134,
+                    25828.9883,
+                    27697.5047,
+                    27956.2276,
+                    29924.4321,
+                    30216.8321,
+                    887896.51,
+                    887068.98,
+                    971549.04,
+                    227921,
+                    230995,
+                    183635,
+                    238605,
+                    254186,
+                ],
+                index=pd.MultiIndex.from_tuples(
+                    [
+                        ("T1", 0),
+                        ("T1", 1),
+                        ("T1", 2),
+                        ("T1", 3),
+                        ("T1", 4),
+                        ("T1", 5),
+                        ("T1", 6),
+                        ("T2", 0),
+                        ("T2", 1),
+                        ("T2", 2),
+                        ("T3", 0),
+                        ("T3", 1),
+                        ("T3", 2),
+                        ("T3", 3),
+                        ("T3", 4),
+                    ],
+                    names=["series_name", "timestamp"],
+                ),
+                columns=["series_value"],
+            ),
+        ),
+    ],
+)
+def test_load_tsf_to_dataframe(input_path, return_type, output_df):
     """Test function for loading tsf format."""
     data_path = os.path.join(
         os.path.dirname(sktime.__file__),
-        "datasets/data/UnitTest/UnitTest_Tsf_Loader.tsf",
+        input_path,
     )
 
-    df, frequency, horizon, missing_values, equal_length = load_tsf_to_dataframe(
-        data_path
-    )
+    expected_metadata = {
+        "frequency": "yearly",
+        "forecast_horizon": 4,
+        "contain_missing_values": False,
+        "contain_equal_length": False,
+    }
 
-    test_df = pd.DataFrame(
+    df, metadata = load_tsf_to_dataframe(data_path, return_type=return_type)
+
+    assert_frame_equal(df, output_df, check_dtype=False)
+    assert metadata == expected_metadata
+    if return_type != "default_tsf":
+        assert check_is_mtype(obj=df, mtype=return_type)
+
+
+@pytest.mark.parametrize("freq", [None, "YS"])
+def test_convert_tsf_to_multiindex(freq):
+    input_df = pd.DataFrame(
         {
             "series_name": ["T1", "T2", "T3"],
             "start_timestamp": [
@@ -1118,8 +1318,56 @@ def test_load_tsf_to_dataframe():
         }
     )
 
-    assert_frame_equal(df, test_df)
-    assert frequency == "yearly"
-    assert horizon == 4
-    assert missing_values is False
-    assert equal_length is False
+    output_df = pd.DataFrame(
+        data=[
+            25092.2284,
+            24271.5134,
+            25828.9883,
+            27697.5047,
+            27956.2276,
+            29924.4321,
+            30216.8321,
+            887896.51,
+            887068.98,
+            971549.04,
+            227921,
+            230995,
+            183635,
+            238605,
+            254186,
+        ],
+        index=pd.MultiIndex.from_tuples(
+            [
+                ("T1", pd.Timestamp(year=1979, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1980, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1981, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1982, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1983, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1984, month=1, day=1)),
+                ("T1", pd.Timestamp(year=1985, month=1, day=1)),
+                ("T2", pd.Timestamp(year=1979, month=1, day=1)),
+                ("T2", pd.Timestamp(year=1980, month=1, day=1)),
+                ("T2", pd.Timestamp(year=1981, month=1, day=1)),
+                ("T3", pd.Timestamp(year=1973, month=1, day=1)),
+                ("T3", pd.Timestamp(year=1974, month=1, day=1)),
+                ("T3", pd.Timestamp(year=1975, month=1, day=1)),
+                ("T3", pd.Timestamp(year=1976, month=1, day=1)),
+                ("T3", pd.Timestamp(year=1977, month=1, day=1)),
+            ],
+            names=["series_name", "timestamp"],
+        ),
+        columns=["series_value"],
+    )
+
+    metadata = {
+        "frequency": "yearly",
+        "forecast_horizon": 4,
+        "contain_missing_values": False,
+        "contain_equal_length": False,
+    }
+
+    assert_frame_equal(
+        output_df,
+        _convert_tsf_to_hierarchical(input_df, metadata, freq=freq),
+        check_dtype=False,
+    )
