@@ -154,7 +154,15 @@ class _Pipeline(
     @property
     def named_steps(self):
         """Map the steps to a dictionary."""
-        return dict(self.steps)
+        return dict(self._steps)
+
+    @property
+    def _steps(self):
+        return self._get_estimator_tuples(self.steps, clone_ests=False)
+
+    @_steps.setter
+    def _steps(self, value):
+        self.steps = value
 
     def get_params(self, deep=True):
         """Get parameters for this estimator.
@@ -170,7 +178,7 @@ class _Pipeline(
         params : mapping of string to any
             Parameter names mapped to their values.
         """
-        return self._get_params("steps", deep=deep)
+        return self._get_params("_steps", deep=deep)
 
     def set_params(self, **kwargs):
         """Set the parameters of this estimator.
@@ -181,7 +189,7 @@ class _Pipeline(
         -------
         self
         """
-        self._set_params("steps", **kwargs)
+        self._set_params("_steps", **kwargs)
         return self
 
     # both children use the same step params for testing, so putting it here
@@ -224,7 +232,9 @@ class _Pipeline(
         ]
         params2 = {"steps": STEPS2}
 
-        return [params1, params2]
+        params3 = {"steps": [ExponentTransformer(), ARIMA()]}
+
+        return [params1, params2, params3]
 
 
 # we ensure that internally we convert to pd.DataFrame for now
@@ -322,7 +332,7 @@ class ForecastingPipeline(_Pipeline):
                 self.steps_[step_idx] = (name, t)
 
         # fit forecaster
-        name, forecaster = self.steps[-1]
+        name, forecaster = self.steps_[-1]
         f = clone(forecaster)
         f.fit(y, X, fh)
         self.steps_[-1] = (name, f)
