@@ -58,7 +58,7 @@ class BaseFixtureGenerator:
     """Fixture generator for base testing functionality in sktime.
 
     Test classes inheriting from this and not overriding pytest_generate_tests
-        will have estimator and scenario fixtures parameterized out of the box.
+        will have estimator and scenario fixtures parametrized out of the box.
 
     Descendants can override:
         estimator_type_filter: str, class variable; None or scitype string
@@ -80,8 +80,8 @@ class BaseFixtureGenerator:
             whether scenario should be skipped in test with test_name test_name
             requires _generate_estimator_scenario as is
 
-    Fixtures parameterized
-    ----------------------
+    Fixtures parametrized
+    ---------------------
     estimator_class: estimator inheriting from BaseObject
         ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
     estimator_instance: instance of estimator inheriting from BaseObject
@@ -99,11 +99,16 @@ class BaseFixtureGenerator:
     # which sequence the conditional fixtures are generated in
     fixture_sequence = ["estimator_class", "estimator_instance", "scenario"]
 
+    # which fixtures are indirect, e.g., have an additional pytest.fixture block
+    #   to generate an indirect fixture at runtime. Example: estimator_instance
+    #   warning: direct fixtures retain state changes within the same test
+    indirect_fixtures = ["estimator_instance"]
+
     def pytest_generate_tests(self, metafunc):
         """Test parameterization routine for pytest.
 
         This uses create_conditional_fixtures_and_names and generator_dict
-        to create the fixtures for a mark.parameterize decoration of all tests.
+        to create the fixtures for a mark.parametrize decoration of all tests.
         """
         # get name of the test
         test_name = metafunc.function.__name__
@@ -124,7 +129,16 @@ class BaseFixtureGenerator:
             raise_exceptions=True,
         )
 
-        metafunc.parametrize(fixture_param_str, fixture_prod, ids=fixture_names)
+        # determine indirect variables for the parametrization block
+        #   this is intersection of self.indirect_vixtures with args in fixture_vars
+        indirect_vars = list(set(fixture_vars).intersection(self.indirect_fixtures))
+
+        metafunc.parametrize(
+            fixture_param_str,
+            fixture_prod,
+            ids=fixture_names,
+            indirect=indirect_vars,
+        )
 
     def _all_estimators(self):
         """Retrieve list of all estimator classes of type self.estimator_type_filter."""
@@ -170,8 +184,8 @@ class BaseFixtureGenerator:
     def _generate_estimator_class(self, test_name, **kwargs):
         """Return estimator class fixtures.
 
-        Fixtures parameterized
-        ----------------------
+        Fixtures parametrized
+        ---------------------
         estimator_class: estimator inheriting from BaseObject
             ranges over all estimator classes not excluded by EXCLUDED_TESTS
         """
@@ -187,8 +201,8 @@ class BaseFixtureGenerator:
     def _generate_estimator_instance(self, test_name, **kwargs):
         """Return estimator instance fixtures.
 
-        Fixtures parameterized
-        ----------------------
+        Fixtures parametrized
+        ---------------------
         estimator_instance: instance of estimator inheriting from BaseObject
             ranges over all estimator classes not excluded by EXCLUDED_TESTS
             instances are generated by create_test_instance class method
@@ -209,11 +223,20 @@ class BaseFixtureGenerator:
 
         return estimator_instances_to_test, estimator_instance_names
 
+    # this is executed before each test instance call
+    #   if this were not executed, estimator_instance would keep state changes
+    #   within executions of the same test with different parameters
+    @pytest.fixture(scope="function")
+    def estimator_instance(self, request):
+        """estimator_instance fixture definition for indirect use."""
+        # esetimator_instance is cloned at the start of every test
+        return clone(request.param)
+
     def _generate_scenario(self, test_name, **kwargs):
         """Return estimator test scenario.
 
-        Fixtures parameterized
-        ----------------------
+        Fixtures parametrized
+        ---------------------
         scenario: instance of TestScenario
             ranges over all scenarios returned by retrieve_scenarios
         """
@@ -344,7 +367,7 @@ class QuickTester:
             return [estimator_class], [estimator_class.__name__]
 
         def _generate_estimator_instance(test_name, **kwargs):
-            return [estimator], [estimator_class.__name__]
+            return [clone(estimator)], [estimator_class.__name__]
 
         def _generate_estimator_instance_cls(test_name, **kwargs):
             return estimator_class.create_test_instances_and_names()
@@ -394,8 +417,8 @@ class QuickTester:
                 raise_exceptions=raise_exceptions,
             )
 
-            # if function is decorated with mark.parameterize, add variable settings
-            # NOTE: currently this works only with single-variable mark.parameterize
+            # if function is decorated with mark.parametrize, add variable settings
+            # NOTE: currently this works only with single-variable mark.parametrize
             if hasattr(test_fun, "pytestmark"):
                 if len([x for x in test_fun.pytestmark if x.name == "parametrize"]) > 0:
                     # get the three lists from pytest
@@ -431,12 +454,12 @@ class QuickTester:
 
                 if return_exceptions:
                     try:
-                        test_fun(**args)
+                        test_fun(**deepcopy(args))
                         results[key] = "PASSED"
                     except Exception as err:
                         results[key] = err
                 else:
-                    test_fun(**args)
+                    test_fun(**deepcopy(args))
                     results[key] = "PASSED"
 
         return results
@@ -467,7 +490,7 @@ class QuickTester:
         Returns
         -------
         pytest_fixture_vars: list of str
-            names of args participating in mark.parameterize marks, in pytest order
+            names of args participating in mark.parametrize marks, in pytest order
         pytest_fixt_list: list of tuple
             list of value tuples from the mark parameterization
             i-th value in each tuple corresponds to i-th arg name in pytest_fixture_vars
@@ -662,6 +685,20 @@ class TestAllEstimators(BaseFixtureGenerator, QuickTester):
         if hasattr(estimator, "predict_proba"):
             assert hasattr(estimator, "predict")
 
+    def test_no_cross_test_side_effects_part1(self, estimator_instance):
+        """Test that there are no side effects across tests, through estimator state."""
+        estimator_instance.test__attr = 42
+
+    def test_no_cross_test_side_effects_part2(self, estimator_instance):
+        """Test that there are no side effects across tests, through estimator state."""
+        assert not hasattr(estimator_instance, "test__attr")
+
+    @pytest.mark.parametrize("a", [True, 42])
+    def test_no_between_test_case_side_effects(self, estimator_instance, scenario, a):
+        """Test that there are no side effects across instances of the same test."""
+        assert not hasattr(estimator_instance, "test__attr")
+        estimator_instance.test__attr = 42
+
     def test_get_params(self, estimator_instance):
         """Check that get_params works correctly."""
         estimator = estimator_instance
