@@ -71,7 +71,7 @@ class Deseasonalizer(BaseTransformer):
         "X_inner_mtype": "pd.Series",
         # which mtypes do _fit/_predict support for X?
         "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
-        "fit-in-transform": False,
+        "fit_is_empty": False,
         "capability:inverse_transform": True,
         "transform-returns-same-time-index": True,
         "univariate-only": True,
@@ -393,6 +393,7 @@ class STLTransformer(_SeriesToSeriesTransformer):
     --------
     Detrender
     Deseasonalizer
+    STLForecaster
 
     References
     ----------
